@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.source_connector_list import SourceConnectorList
+from myst.openapi.models.source_connector_list import SourceConnectorList
 
 
 def request_sync(client: Client) -> SourceConnectorList:
