@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.model_connector_get import ModelConnectorGet
+from myst.openapi.models.model_connector_get import ModelConnectorGet
 
 
 class ModelConnectorList(base_model.BaseModel):
