@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.model_get import ModelGet
+from myst.openapi.models.model_get import ModelGet
 
 
 class ModelList(base_model.BaseModel):
