@@ -4,9 +4,8 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.deploy_status import DeployStatus
-from ..models.time_dataset_spec import TimeDatasetSpec
+from myst.openapi.models.deploy_status import DeployStatus
+from myst.openapi.models.time_dataset_spec import TimeDatasetSpec
 
 
 class ModelUpdate(base_model.BaseModel):
