@@ -1,9 +1,8 @@
 from typing import List, Union
 
 from myst.models import base_model
-
-from ..models.model_fit_policy_get import ModelFitPolicyGet
-from ..models.time_series_run_policy_get import TimeSeriesRunPolicyGet
+from myst.openapi.models.model_fit_policy_get import ModelFitPolicyGet
+from myst.openapi.models.time_series_run_policy_get import TimeSeriesRunPolicyGet
 
 
 class ProjectPoliciesList(base_model.BaseModel):
