@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.source_connector_get import SourceConnectorGet
+from myst.openapi.models.source_connector_get import SourceConnectorGet
 
 
 class SourceConnectorList(base_model.BaseModel):
