@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.source_run_result_get import SourceRunResultGet
+from myst.openapi.models.source_run_result_get import SourceRunResultGet
 
 
 class SourceRunResultList(base_model.BaseModel):
