@@ -4,8 +4,7 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.time_dataset_row import TimeDatasetRow
+from myst.openapi.models.time_dataset_row import TimeDatasetRow
 
 
 class TimeDataset(base_model.BaseModel):
