@@ -183,3 +183,46 @@ def example_layer(example_time_series: Dict[str, Any]) -> Dict[str, Any]:
         start_timing=None,
         end_timing=None,
     )
+
+
+@pytest.fixture
+def example_backtest(example_project: Dict[str, Any], example_model: Dict[str, Any]) -> Dict[str, Any]:
+    fit_start_timing_str = "-P1Y"
+    fit_end_timing_str = "PT0H"
+    predict_start_timing_str = "PT1H"
+    predict_end_timing_str = "PT6H"
+
+    return dict(
+        object="Backtest",
+        uuid="6c219892-5d88-40d8-85d4-56170f752336",
+        project=example_project["uuid"],
+        create_time="2021-09-15T22:36:44Z",
+        update_time=None,
+        creator="fb80ae8a-dc73-45f3-9a49-ca57202b8fdf",
+        owner="fb80ae8a-dc73-45f3-9a49-ca57202b8fdf",
+        title="example_backtest",
+        description=None,
+        model=example_model["uuid"],
+        test_start_time="2020-01-01T00:00:00Z",
+        test_end_time="2021-01-01T00:00:00Z",
+        fit_start_timing=dict(object="Timing", type="RelativeTiming", offset=fit_start_timing_str, time_zone=None),
+        fit_end_timing=dict(object="Timing", type="RelativeTiming", offset=fit_end_timing_str, time_zone=None),
+        fit_reference_timing=dict(object="Timing", type="CronTiming", cron_expression="0 0 * * 0", time_zone="UTC"),
+        predict_start_timing=dict(
+            object="Timing", type="RelativeTiming", offset=predict_start_timing_str, time_zone="UTC"
+        ),
+        predict_end_timing=dict(object="Timing", type="RelativeTiming", offset=predict_end_timing_str, time_zone="UTC"),
+        predict_reference_timing=dict(object="Timing", type="CronTiming", cron_expression="0 * * * *", time_zone="UTC"),
+    )
+
+
+@pytest.fixture
+def example_result() -> Dict[str, Any]:
+    return dict(
+        object="BacktestResult",
+        uuid="37faf8b5-5a4e-40e5-b90a-439a9743f921",
+        create_time="2021-03-17T00:00:09Z",
+        start_time="2021-03-17T00:00:10Z",
+        end_time="2021-03-17T00:03:42Z",
+        result_url="https://storage.cloud.google.com/backtest-result/37faf8b5-5a4e-40e5-b90a-439a9743f921.json",
+    )
